local harbour = ...

-- White scroll -------------------------------------------------------------------------------------
harbour:registerAssetId("icons/scrollWhite.png", "ICON_BV1_WHITE_SCROLL", "ATLAS_CELL")

-- Default Balancing (event list) ---------------------------------------------------------------------------------------------
harbour:overrideAsset({
    Id = "DEFAULT_BALANCING",
    EventList = {
        Action = "APPEND",
        HarbourPrefix .. "_EVENT_SETUP_250",
        HarbourPrefix .. "_EVENT_SETUP_500",
        HarbourPrefix .. "_EVENT_SETUP_1000",
        HarbourPrefix .. "_EVENT_SETUP_1500",
    }
})

function registerQuestExport(_quantity)
    harbour:registerAsset({
	DataType = "RESOURCE",
	Id = "BV1_WHITE_SCROLL_" .. _quantity,
	ResourceName = "BV1_WHITE_SCROLL_NAME",
	Icon = "ICON_BV1_WHITE_SCROLL",
	ResourceTypeList = { "RESOURCE" },
	IsTradable = true,
	VillagerBuyingPrice = { Resource = "GOLD", Quantity = 50 },
        DisplayInInventory = true,
--        DisplayInToolbar = true,
    })

    -- Event: Setup ---------------------------------------------------------------------------------------------
    harbour:registerAsset({
        DataType = "EVENT",
        Id = HarbourPrefix .. "_EVENT_SETUP_" .. _quantity,
        Title = HarbourPrefix .. "_EVENT_SETUP_NAME",
        Description = HarbourPrefix .. "_EVENT_SETUP_DESC",
        IsInMainPool = false, -- the main pool seems to suppress itself until the first Weather event fires, so custom events should be outside the main pool
        IsRecurrent = true,
        DaysToFirst = 1, -- number of days from the start of the game (setting = 5 will fire the event at the start of Day 5). 
        ConditionList = {
            {
                DataType = "EVENT_CONDITION_BUILDING_BUILT",
                AssetBuilding = "BUILDING_VILLAGE_CENTER"
            }
        },
        ActionList = {
            {
                DataType = "EVENT_ACTION_GIVE_QUEST",
                Quest = HarbourPrefix .. "_QUEST_WHITE_SCROLL_" .. _quantity,
            },
        }
    })

    -- Quest ---------------------------------------------------------------------------------------------
    harbour:registerAsset({
        DataType = "QUEST",
        Id = HarbourPrefix .. "_QUEST_WHITE_SCROLL_" .. _quantity,
        Name = HarbourPrefix .. "_QUEST_WHITE_SCROLL_NAME",
        Description = HarbourPrefix .. "_QUEST_WHITE_SCROLL_DESC",
        IsSilent = true,
        QuestFunction = {
            DataType = "QUEST_FUNCTION_PRODUCE_RESOURCE",
            Resource = "BV1_WHITE_SCROLL_" .. _quantity,
        },
        QuestRewardActionList = {
--[[
            {
                DataType = "ACTION_SHOW_NARRATIVE_PANEL",
                NarrativePanelData = {
                    DataType = "DATA_NARRATIVE_PANEL",
                    Title = HarbourPrefix .. "EVENT_SECURITY_START_TITLE",
                    Description = HarbourPrefix .. "EVENT_SECURITY_START_DESC",
                    PanelVisual = "ILLUSTRATION_EVENT_WAR",
                },
                ChoiceList = {
                    {
                        DataType = "EVENT_CHOICE",
                        ShortName = "EVENT_SECURITY_OK",
                        EventActionList = {
                            {
                                DataType = "EVENT_ACTION_IGNORE"
                            },
                        },
                    }
                },
            },
--]]
            {
                DataType = "EVENT_ACTION_PAY",
                AmountToPay = {
                    {
                        Resource = "BV1_WHITE_SCROLL_" .. _quantity,
                        Quantity = 1,
                    },
                    {
                        Resource = "GOLD_COINS",
                        Quantity = -_quantity,
                    },
                },
            },
        },
        QuestFailActionList = nil,
        QuestListToUnlockAfter = nil,
        OnFailCallback = nil,
        OnSuccessCallback = {
            DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
            Event = HarbourPrefix .. "_EVENT_SETUP_" .. _quantity,
        }
    })
end

registerQuestExport(250)
registerQuestExport(500)
registerQuestExport(1000)
registerQuestExport(1500)
